@@ -829,10 +829,9 @@ __miaui_glview_instance_init (GTypeInstance * instance, gpointer UNUSED(g_class)
 	self->lmouse_move_handler = lmouse_rotate;
 
 	self->lightpos = mia_vector3d_new (-10, 2, -24);
-	self->camera = mia_camera_new (mia_vector3d_new (0, 0, 0),
+	self->camera = mia_camera_new (mia_vector3d_new (0, 0, 250),
 				       mia_quaternion_new (0.0, 0.0,
-							   0.0, 1.0),
-				       250, 1.0);
+							   0.0, 1.0), 1.0);
 	self->clipplane_far = 300;
 	self->clipplane_near = 200;
 	/* mia_quaternion_new(-0.212891, 0.731839, -0.615647, 0.200170), */
